=====
Usage
=====

To use taurenmd in a project::

	import taurenmd

After installation run the following command to access the client interface::

    taurenmd

You can run a specific interface as follows::

    taurenmd trajedit
